@@ -6,23 +6,23 @@ def test_rests_to_multimeasure_rest_01():
     container = abjad.Container(r"r1")
     auxjad.rests_to_multimeasure_rest(container)
     assert format(container) == abjad.String.normalize(
-        r'''
+        r"""
         {
             R1
         }
-        ''')
+        """)
 
 
 def test_rests_to_multimeasure_rest_02():
     container = abjad.Container(r"\time 3/4 r4 r8.. r32 r4")
     auxjad.rests_to_multimeasure_rest(container)
     assert format(container) == abjad.String.normalize(
-        r'''
+        r"""
         {
             %%% \time 3/4 %%%
             R1 * 3/4
         }
-        ''')
+        """)
 
 
 def test_rests_to_multimeasure_rest_03():
@@ -32,7 +32,7 @@ def test_rests_to_multimeasure_rest_03():
                                 )
     auxjad.rests_to_multimeasure_rest(container)
     assert format(container) == abjad.String.normalize(
-        r'''
+        r"""
         {
             %%% \time 3/4 %%%
             R1 * 3/4
@@ -44,4 +44,4 @@ def test_rests_to_multimeasure_rest_03():
             c'4
             R1 * 5/4
         }
-        ''')
+        """)
